Python module providing access to DIA DB information.
=====================================================

.. image:: https://git.km3net.de/km3py/km3dia/badges/master/pipeline.svg
    :target: https://git.km3net.de/km3py/km3dia/pipelines

.. image:: https://git.km3net.de/km3py/km3dia/badges/master/coverage.svg
    :target: https://vpestel.pages.km3net.de/km3dia/coverage

.. image:: https://git.km3net.de/examples/km3badges/-/raw/master/docs-latest-brightgreen.svg
    :target: https://vpestel.pages.km3net.de/km3dia

